@@ -4,7 +4,7 @@ import { DeleteModalTrigger } from "./DeleteModalTrigger";
 import React, { Component } from "react";
 import PropTypes from "prop-types";
 import isEmpty from "lodash/isEmpty";
-import { ResourceActions } from "./ResourceActions";
+import ResourceActions from "./ResourceActions";
 import { Button, Dropdown } from "semantic-ui-react";
 import { i18next } from "@translations/invenio_administration/i18next";
 import _get from "lodash/get";
@@ -21,13 +21,15 @@ export class Actions extends Component {
       editUrl,
       displayEdit,
       displayDelete,
+      displayAsDropdown,
     } = this.props;
 
     // if number of actions is greater than 3, we display all in a dropdown
-    const displayAsDropdown =
-      displayEdit && displayDelete && Object.keys(actions).length > 1;
+    const _displayAsDropdown =
+      displayAsDropdown ||
+      (displayEdit && displayDelete && Object.keys(actions).length > 1);
 
-    if (displayAsDropdown) {
+    if (_displayAsDropdown) {
       return (
         <Dropdown>
           {!isEmpty(actions) && (
@@ -63,7 +65,7 @@ export class Actions extends Component {
       );
     } else {
       return (
-        <Button.Group size="tiny" className="relaxed">
+        <>
           {!isEmpty(actions) && (
             <ResourceActions
               resource={resource}
@@ -81,7 +83,7 @@ export class Actions extends Component {
               title={title}
             />
           )}
-        </Button.Group>
+        </>
       );
     }
   }
@@ -92,6 +94,7 @@ Actions.propTypes = {
   resourceName: PropTypes.string.isRequired,
   displayEdit: PropTypes.bool,
   displayDelete: PropTypes.bool,
+  displayAsDropdown: PropTypes.bool,
   resource: PropTypes.object.isRequired,
   successCallback: PropTypes.func.isRequired,
   idKeyPath: PropTypes.string,
@@ -102,5 +105,6 @@ Actions.propTypes = {
 Actions.defaultProps = {
   displayEdit: true,
   displayDelete: true,
+  displayAsDropdown: false,
   idKeyPath: "pid",
 };
