@@ -1,12 +1,12 @@
 import { APIRoutes } from "./routes";
-import { http } from "./config";
+import { http } from "react-invenio-forms";
 
-const getResource = async (apiEndpoint, pid) => {
-  return await http.get(APIRoutes.get(apiEndpoint, pid));
+const getResource = async (apiEndpoint, pid, requestHeaders) => {
+  return await http.get(APIRoutes.get(apiEndpoint, pid), { headers: requestHeaders });
 };
 
-const deleteResource = async (resource, apiEndpoint, idKeyPath = "pid") => {
-  return await http.delete(APIRoutes.detailsView(apiEndpoint, resource, idKeyPath));
+const deleteResource = async (apiEndpoint) => {
+  return await http.delete(apiEndpoint);
 };
 
 const editResource = async (apiEndpoint, pid, payload) => {
@@ -21,10 +21,16 @@ const resourceAction = async (endpoint, payload) => {
   return await http.post(endpoint, payload);
 };
 
+const getSchema = async (endpoint, id) => {
+  const serializedEndpoint = endpoint.replace("<item_id>", id);
+  return await http.get(serializedEndpoint);
+};
+
 export const InvenioAdministrationActionsApi = {
   deleteResource: deleteResource,
   editResource: editResource,
   getResource: getResource,
   resourceAction: resourceAction,
   createResource: createResource,
+  getSchema: getSchema,
 };
