@@ -14,6 +14,10 @@ class DateFormatter extends React.Component {
   render() {
     const { value } = this.props;
 
+    if (!value) {
+      return null;
+    }
+
     const date = DateTime.fromISO(value);
     return (
       <p data-testid="date-formatter">{date.toLocaleString(DateTime.DATETIME_MED)}</p>
