@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2022 CERN.
+# Copyright (C) 2019-2024 CERN.
 # Copyright (C) 2019-2022 Northwestern University.
 # Copyright (C)      2022 TU Wien.
 # Copyright (C)      2022 Graz University of Technology.
@@ -19,16 +19,11 @@ theme = WebpackThemeBundle(
     themes={
         "semantic-ui": dict(
             entry={
-                "invenio-administration-search":
-                    "./js/invenio_administration/src/search/search.js",
-                "invenio-administration-edit":
-                    "./js/invenio_administration/src/edit/edit.js",
-                "invenio-administration-create":
-                    "./js/invenio_administration/src/create/create.js",
-                "base-admin-theme":
-                    "./js/invenio_administration/src/theme.js",
-                "invenio-administration-details":
-                    "./js/invenio_administration/src/details/details.js"
+                "invenio-administration-search": "./js/invenio_administration/src/search/search.js",
+                "invenio-administration-edit": "./js/invenio_administration/src/edit/edit.js",
+                "invenio-administration-create": "./js/invenio_administration/src/create/create.js",
+                "base-admin-theme": "./js/invenio_administration/src/theme.js",
+                "invenio-administration-details": "./js/invenio_administration/src/details/details.js",
             },
             dependencies={
                 "@babel/runtime": "^7.9.0",
@@ -39,7 +34,7 @@ theme = WebpackThemeBundle(
                 "prop-types": "^15.7.2",
                 "react-copy-to-clipboard": "^5.0.0",
                 "react-i18next": "^11.11.0",
-                "react-invenio-forms": "^1.0.0",
+                "react-invenio-forms": "^4.0.0",
                 "react-searchkit": "^2.0.0",
                 "yup": "^0.32.0",
                 "formik": "^2.2.9",
@@ -50,8 +45,7 @@ theme = WebpackThemeBundle(
                 # entry point). theme.config itself is provided by
                 # cookiecutter-invenio-rdm.
                 "@js/invenio_administration": "js/invenio_administration",
-                "@translations/invenio_administration":
-                    "translations/invenio_administration",
+                "@translations/invenio_administration": "translations/invenio_administration",
             },
         ),
     },
